summaryrefslogtreecommitdiff
path: root/forms/source
diff options
context:
space:
mode:
Diffstat (limited to 'forms/source')
-rw-r--r--forms/source/component/Columns.cxx2
-rw-r--r--forms/source/component/DatabaseForm.cxx4
-rw-r--r--forms/source/component/FormComponent.cxx6
-rw-r--r--forms/source/component/ListBox.cxx2
-rw-r--r--forms/source/component/RadioButton.hxx2
-rw-r--r--forms/source/component/clickableimage.cxx2
-rw-r--r--forms/source/component/propertybaghelper.cxx2
-rw-r--r--forms/source/inc/FormComponent.hxx4
-rw-r--r--forms/source/richtext/richtextcontrol.cxx4
-rw-r--r--forms/source/richtext/richtextcontrol.hxx2
-rw-r--r--forms/source/richtext/richtextimplcontrol.cxx6
-rw-r--r--forms/source/solar/component/navbarcontrol.cxx4
-rw-r--r--forms/source/solar/component/navbarcontrol.hxx2
-rw-r--r--forms/source/solar/inc/navtoolbar.hxx2
-rw-r--r--forms/source/xforms/binding.cxx4
-rw-r--r--forms/source/xforms/convert.hxx2
-rw-r--r--forms/source/xforms/datatypes.hxx4
-rw-r--r--forms/source/xforms/model.cxx2
-rw-r--r--forms/source/xforms/model_ui.cxx2
19 files changed, 29 insertions, 29 deletions
diff --git a/forms/source/component/Columns.cxx b/forms/source/component/Columns.cxx
index c307de658074..484ce1c9ef5f 100644
--- a/forms/source/component/Columns.cxx
+++ b/forms/source/component/Columns.cxx
@@ -194,7 +194,7 @@ Sequence<Type> SAL_CALL OGridColumn::getTypes() throw(RuntimeException)
Any SAL_CALL OGridColumn::queryAggregation( const Type& _rType ) throw (RuntimeException)
{
Any aReturn;
- // some functionality at our aggregate cannot be reasonably fullfilled here.
+ // some functionality at our aggregate cannot be reasonably fulfilled here.
if ( _rType.equals(::getCppuType(static_cast< Reference< XFormComponent >* >(NULL)))
|| _rType.equals(::getCppuType(static_cast< Reference< XServiceInfo >* >(NULL)))
|| _rType.equals(::getCppuType(static_cast< Reference< XBindableValue >* >(NULL)))
diff --git a/forms/source/component/DatabaseForm.cxx b/forms/source/component/DatabaseForm.cxx
index 7ab4b71fe59e..a7012ca7fcc6 100644
--- a/forms/source/component/DatabaseForm.cxx
+++ b/forms/source/component/DatabaseForm.cxx
@@ -90,7 +90,7 @@
#include <ctype.h>
#include <hash_map>
-// compatiblity: DatabaseCursorType is dead, but for compatiblity reasons we still have to write it ...
+// compatibility: DatabaseCursorType is dead, but for compatibility reasons we still have to write it ...
namespace com {
namespace sun {
namespace star {
@@ -3099,7 +3099,7 @@ void SAL_CALL ODatabaseForm::rowSetChanged(const EventObject& /*event*/) throw(
// if our parent is an ODatabaseForm, too, then after this rowSetChanged we'll get a "reloaded"
// or a "loaded" event.
// If somebody gave us another parent which is an XRowSet but doesn't handle an execute as
- // "load" respectivly "reload" ... can't do anything ....
+ // "load" respectively "reload" ... can't do anything ....
}
//------------------------------------------------------------------------------
diff --git a/forms/source/component/FormComponent.cxx b/forms/source/component/FormComponent.cxx
index 34ad5eabd7e0..73cf49db0cb1 100644
--- a/forms/source/component/FormComponent.cxx
+++ b/forms/source/component/FormComponent.cxx
@@ -1330,7 +1330,7 @@ OBoundControlModel::OBoundControlModel(
m_aValuePropertyType = _pOriginal->m_aValuePropertyType;
m_aControlSource = _pOriginal->m_aControlSource;
m_bInputRequired = _pOriginal->m_bInputRequired;
- // m_xLabelControl, though being a property, is not to be cloned, not even the reference will be transfered.
+ // m_xLabelControl, though being a property, is not to be cloned, not even the reference will be transferred.
// (the former should be clear - a clone of the object we're only referencing does not make sense)
// (the second would violate the restriction for label controls that they're part of the
// same form component hierarchy - we ourself are no part, yet, so we can't have a label control)
@@ -1967,7 +1967,7 @@ void SAL_CALL OBoundControlModel::propertyChange( const PropertyChangeEvent& evt
// if the DBColumn value changed, transfer it to the control
if ( evt.PropertyName.equals( PROPERTY_VALUE ) )
{
- OSL_ENSURE( evt.Source == getField(), "OBoundControlModel::propertyChange: value changes from components other than our database colum?" );
+ OSL_ENSURE( evt.Source == getField(), "OBoundControlModel::propertyChange: value changes from components other than our database column?" );
osl::MutexGuard aGuard(m_aMutex);
if ( m_bForwardValueChanges && m_xColumn.is() )
transferDbValueToControl();
@@ -2246,7 +2246,7 @@ void OBoundControlModel::impl_connectDatabaseColumn_noNotify( bool _bFromReload
}
// now that we're connected (more or less, even if we did not find a column),
- // we definately want to forward any potentially occuring value changes
+ // we definitely want to forward any potentially occurring value changes
m_bForwardValueChanges = sal_True;
// let derived classes react on this new connection
diff --git a/forms/source/component/ListBox.cxx b/forms/source/component/ListBox.cxx
index 65c6e7cee269..db395a5b2946 100644
--- a/forms/source/component/ListBox.cxx
+++ b/forms/source/component/ListBox.cxx
@@ -1257,7 +1257,7 @@ namespace frm
{
Any aReturn;
- // by definition, multiple selected entries are transfered as NULL if the
+ // by definition, multiple selected entries are transferred as NULL if the
// binding does not support string lists
if ( _rSelectSequence.getLength() <= 1 )
{
diff --git a/forms/source/component/RadioButton.hxx b/forms/source/component/RadioButton.hxx
index dc9c85f7b375..7e59f7984a77 100644
--- a/forms/source/component/RadioButton.hxx
+++ b/forms/source/component/RadioButton.hxx
@@ -77,7 +77,7 @@ protected:
private:
/** sets the given value as new State at the aggregate
@precond
- our mutex is aquired exactly once
+ our mutex is acquired exactly once
*/
void setNewAggregateState( const ::com::sun::star::uno::Any& _rValue );
};
diff --git a/forms/source/component/clickableimage.cxx b/forms/source/component/clickableimage.cxx
index a159a91ce2b4..3a63e7010a9d 100644
--- a/forms/source/component/clickableimage.cxx
+++ b/forms/source/component/clickableimage.cxx
@@ -600,7 +600,7 @@ namespace frm
Any SAL_CALL OClickableImageBaseModel::queryAggregation(const Type& _rType) throw (RuntimeException)
{
// order matters:
- // we definately want to "overload" the XImageProducer interface of our aggregate,
+ // we definitely want to "overload" the XImageProducer interface of our aggregate,
// thus check OClickableImageBaseModel_Base (which provides this) first
Any aReturn = OClickableImageBaseModel_Base::queryInterface( _rType );
diff --git a/forms/source/component/propertybaghelper.cxx b/forms/source/component/propertybaghelper.cxx
index 6222435ab828..7876858620ee 100644
--- a/forms/source/component/propertybaghelper.cxx
+++ b/forms/source/component/propertybaghelper.cxx
@@ -131,7 +131,7 @@ namespace frm
if ( ( nHandle != -1 ) && rPropInfo.fillPropertyMembersByHandle( NULL, NULL, nHandle ) )
nHandle = -1;
- // seach a free handle in <math>F_1009</math>
+ // search a free handle in <math>F_1009</math>
if ( nHandle == -1 )
{
sal_Int32 nPrime = 1009;
diff --git a/forms/source/inc/FormComponent.hxx b/forms/source/inc/FormComponent.hxx
index 88a62abdf368..86eb85a2b1d3 100644
--- a/forms/source/inc/FormComponent.hxx
+++ b/forms/source/inc/FormComponent.hxx
@@ -194,7 +194,7 @@ public:
the aggregate. In this case, you <em>have</em> to call doSetDelegator within your
own constructor.
- This is helpfull, if your derived class wants to cache an interface of the aggregate.
+ This is helpful, if your derived class wants to cache an interface of the aggregate.
In this case, the aggregate needs to be queried for this interface <b>before</b> the
<member scope="com::sun::star::uno">XAggregation::setDelegator</member> call.
@@ -674,7 +674,7 @@ private:
const sal_Bool m_bSupportsExternalBinding : 1; // do we support XBindableValue?
const sal_Bool m_bSupportsValidation : 1; // do we support XValidatable?
sal_Bool m_bForwardValueChanges : 1; // do we currently handle changes in the bound database field?
- sal_Bool m_bTransferingValue : 1; // true if we're currently transfering our value to an external binding
+ sal_Bool m_bTransferingValue : 1; // true if we're currently transferring our value to an external binding
sal_Bool m_bIsCurrentValueValid : 1; // flag specifying whether our current value is valid, relative to our external validator
sal_Bool m_bBindingControlsRO : 1; // is our ReadOnly property currently controlled by our external binding?
sal_Bool m_bBindingControlsEnable : 1; // is our Enabled property currently controlled by our external binding?
diff --git a/forms/source/richtext/richtextcontrol.cxx b/forms/source/richtext/richtextcontrol.cxx
index ffdece17b2c1..57bb9b6965f9 100644
--- a/forms/source/richtext/richtextcontrol.cxx
+++ b/forms/source/richtext/richtextcontrol.cxx
@@ -243,7 +243,7 @@ namespace frm
DBG_ASSERT( pPeer, "ORichTextControl::createPeer: invalid peer returned!" );
if ( pPeer )
{
- // by definition, the returned component is aquired once
+ // by definition, the returned component is acquired once
pPeer->release();
// announce the peer to the base class
@@ -344,7 +344,7 @@ namespace frm
// the peer itself
ORichTextPeer* pPeer = new ORichTextPeer;
- pPeer->acquire(); // by definition, the returned object is aquired once
+ pPeer->acquire(); // by definition, the returned object is acquired once
// the VCL control for the peer
RichTextControl* pRichTextControl = new RichTextControl( pEngine, _pParentWindow, _nStyle, NULL, pPeer );
diff --git a/forms/source/richtext/richtextcontrol.hxx b/forms/source/richtext/richtextcontrol.hxx
index 2298fee9195b..6959bfd929d0 100644
--- a/forms/source/richtext/richtextcontrol.hxx
+++ b/forms/source/richtext/richtextcontrol.hxx
@@ -109,7 +109,7 @@ namespace frm
public:
/** factory method
@return
- a new ORichTextPeer instance, which has been aquired once!
+ a new ORichTextPeer instance, which has been acquired once!
*/
static ORichTextPeer* Create(
const ::com::sun::star::uno::Reference< ::com::sun::star::awt::XControlModel >& _rxModel,
diff --git a/forms/source/solar/component/navbarcontrol.cxx b/forms/source/solar/component/navbarcontrol.cxx
index e0ffc53d619b..3101ef4fbb7f 100644
--- a/forms/source/solar/component/navbarcontrol.cxx
+++ b/forms/source/solar/component/navbarcontrol.cxx
@@ -180,7 +180,7 @@ namespace frm
ONavigationBarPeer* pPeer = ONavigationBarPeer::Create( maContext.getLegacyServiceFactory(), pParentWin, getModel() );
DBG_ASSERT( pPeer, "ONavigationBarControl::createPeer: invalid peer returned!" );
if ( pPeer )
- // by definition, the returned component is aquired once
+ // by definition, the returned component is acquired once
pPeer->release();
// announce the peer to the base class
@@ -275,7 +275,7 @@ namespace frm
// the peer itself
ONavigationBarPeer* pPeer = new ONavigationBarPeer( _rxORB );
- pPeer->acquire(); // by definition, the returned object is aquired once
+ pPeer->acquire(); // by definition, the returned object is acquired once
// the VCL control for the peer
Reference< XModel > xContextDocument( getXModel( _rxModel ) );
diff --git a/forms/source/solar/component/navbarcontrol.hxx b/forms/source/solar/component/navbarcontrol.hxx
index 3d8b12994866..d574553269a2 100644
--- a/forms/source/solar/component/navbarcontrol.hxx
+++ b/forms/source/solar/component/navbarcontrol.hxx
@@ -99,7 +99,7 @@ namespace frm
public:
/** factory method
@return
- a new ONavigationBarPeer instance, which has been aquired once!
+ a new ONavigationBarPeer instance, which has been acquired once!
*/
static ONavigationBarPeer* Create(
const ::com::sun::star::uno::Reference< ::com::sun::star::lang::XMultiServiceFactory >& _rxORB,
diff --git a/forms/source/solar/inc/navtoolbar.hxx b/forms/source/solar/inc/navtoolbar.hxx
index bc6464c04717..787eb9e6fab6 100644
--- a/forms/source/solar/inc/navtoolbar.hxx
+++ b/forms/source/solar/inc/navtoolbar.hxx
@@ -85,7 +85,7 @@ namespace frm
then the states of the features are updated
@param _pDispatcher
- the new (or old) dispatcher. The caller is reponsible for
+ the new (or old) dispatcher. The caller is responsible for
ensuring the life time of the object does exceed the life time
of the tool bar instance.
*/
diff --git a/forms/source/xforms/binding.cxx b/forms/source/xforms/binding.cxx
index c1722b8ab081..0f7e6ac45279 100644
--- a/forms/source/xforms/binding.cxx
+++ b/forms/source/xforms/binding.cxx
@@ -674,7 +674,7 @@ void Binding::bind( bool bForceRebind )
}
}
- // now evaluate remaining MIPs in the apropriate context
+ // now evaluate remaining MIPs in the appropriate context
maReadonly.evaluate( rContext );
maRelevant.evaluate( rContext );
maRequired.evaluate( rContext );
@@ -1274,7 +1274,7 @@ void Binding::handleEvent( const XEvent_t& xEvent )
// the modification of the 'mnDeferModifyNotifications'-member
// is necessary to prevent infinite notication looping.
- // This can happend in case the binding which caused
+ // This can happened in case the binding which caused
// the notification chain is listening to those events
// as well...
bool bPreserveValueModified = mbValueModified;
diff --git a/forms/source/xforms/convert.hxx b/forms/source/xforms/convert.hxx
index 4cd804ca098f..035902149a2b 100644
--- a/forms/source/xforms/convert.hxx
+++ b/forms/source/xforms/convert.hxx
@@ -94,7 +94,7 @@ public:
sal_Int16 _nWhitespaceTreatment
);
- /** replace all occurences 0x08, 0x0A, 0x0D with 0x20
+ /** replace all occurrences 0x08, 0x0A, 0x0D with 0x20
*/
static ::rtl::OUString replaceWhitespace( const ::rtl::OUString& _rString );
diff --git a/forms/source/xforms/datatypes.hxx b/forms/source/xforms/datatypes.hxx
index 9bcb3c1f0c0a..cb0dadc74cf9 100644
--- a/forms/source/xforms/datatypes.hxx
+++ b/forms/source/xforms/datatypes.hxx
@@ -219,11 +219,11 @@ namespace xforms
The normalization must respect the "<" and "==" relations on the value
space. That is, if two values are equal, their normalizations must be equal, too.
- Similarily, if <code>foo</code> is less than <code>bar</code>, the same
+ Similarly, if <code>foo</code> is less than <code>bar</code>, the same
must hold for their normalizations.
@param _rValue
- the value to translate. Guranteed to be not <NULL/>, and of type <member>ValueType</member>
+ the value to translate. Guaranteed to be not <NULL/>, and of type <member>ValueType</member>
@param _rDoubleValue
output parameter to hold the resulting double value
*/
diff --git a/forms/source/xforms/model.cxx b/forms/source/xforms/model.cxx
index 7f6bd4effca6..6162b3848a6a 100644
--- a/forms/source/xforms/model.cxx
+++ b/forms/source/xforms/model.cxx
@@ -289,7 +289,7 @@ void Model::dbg_assertInvariant() const
//
-// MIP managment
+// MIP management
//
void Model::addMIP( void* pTag, const XNode_t& xNode, const MIP& rMIP )
diff --git a/forms/source/xforms/model_ui.cxx b/forms/source/xforms/model_ui.cxx
index b440b2972d78..4c3a203b0350 100644
--- a/forms/source/xforms/model_ui.cxx
+++ b/forms/source/xforms/model_ui.cxx
@@ -134,7 +134,7 @@ void lcl_OutPosition( OUStringBuffer& rBuffer,
{
OSL_ENSURE( xNode->getParentNode().is(), "need parent" );
- // count # of occurences of this node
+ // count # of occurrences of this node
sal_Int32 nFound = 0;
sal_Int32 nPosition = -1;
if( xNode->getParentNode().is() )
diff --git a/forms/source/richtext/richtextimplcontrol.cxx b/forms/source/richtext/richtextimplcontrol.cxx
index 21749f091b13..222c7878fe61 100644
--- a/forms/source/richtext/richtextimplcontrol.cxx
+++ b/forms/source/richtext/richtextimplcontrol.cxx
@@ -67,7 +67,7 @@ namespace frm
,m_bHasEverBeenShown ( false )
{
OSL_ENSURE( m_pAntiImpl, "RichTextControlImpl::RichTextControlImpl: invalid window!" );
- OSL_ENSURE( m_pEngine, "RichTextControlImpl::RichTextControlImpl: invalid edit engine! This will *definately* crash!" );
+ OSL_ENSURE( m_pEngine, "RichTextControlImpl::RichTextControlImpl: invalid edit engine! This will *definitely* crash!" );
m_pViewport = new RichTextViewPort( m_pAntiImpl );
m_pViewport->setAttributeInvalidationHandler( LINK( this, RichTextControlImpl, OnInvalidateAllAttributes ) );
@@ -124,7 +124,7 @@ namespace frm
// type (Latin, Asian, Complex). However, if we have an observer who is interested
// in the state of this attribute, we have to kind of *merge* the three attributes
// to only one.
- // This is usefull in case the observer is for instance a toolbox which contains only
+ // This is useful in case the observer is for instance a toolbox which contains only
// an, e.g., "bold" slot, and thus not interested in the particular script type of the
// current selection.
SvxScriptSetItem aNormalizedSet( (WhichId)_pHandler->first, *m_pView->GetAttribs().GetPool() );
@@ -307,7 +307,7 @@ namespace frm
// the AutoPaperSize bits set.
// So in order to be properly notified, we would need the AutoPaperSize. But, with
// AutoPaperSize, other things do not work anymore: Either, when we set a MaxAutoPaperSize,
// then the view does automatic soft line breaks at the paper end - which we definately do
// want. Or, if we did not set a MaxAutoPaperSize, then the view does not automatically scroll
// anymore in horizontal direction.
// So this is some kind of lose-lose situation ... :(
@@ -307,7 +307,7 @@ namespace frm
// So in order to be properly notified, we would need the AutoPaperSize. But, with
// AutoPaperSize, other things do not work anymore: Either, when we set a MaxAutoPaperSize,
- // then the view does automatic soft line breaks at the paper end - which we definately do
+ // then the view does automatic soft line breaks at the paper end - which we definitely do
// want. Or, if we did not set a MaxAutoPaperSize, then the view does not automatically scroll
// anymore in horizontal direction.